@@ -6,7 +6,7 @@
 #
 #  Authors: Mikhail Mamrov <m.mamrov@abm-jsc.ru>
 #
-from pollution_detector_connector.pollution_settings import PollutionSettings
+from pollution_detector_connector.pollution_settings import PollutionSettings, ImageBox
 from pollution_detector_connector.pollution_detector_connector import PollutionDetectorConnector
 from pollution_detector_connector.pollution_detector_http_connector import PollutionDetectorHttpConnector
 from pollution_detector_connector.pollution_detector_kafka_connector import PollutionDetectorKafkaConnector
